@@ -9,10 +9,11 @@ typedef struct
 {
 	PyObject_HEAD
 	PyObject *files;
-	PyObject *arg;
 	metalink_t *metalink;
 } cMetalinkObject;
 
 PyObject *libmetalinkException;
 
+static uint8_t cMetalink_createPyObject(cMetalinkObject *self, __attribute__((unused)) PyObject *args);
+
 #endif /* LIBMETALINK_H */
